@@ -20,9 +20,10 @@ from ai.h2o.sparkling.ml.params.H2OTypeConverters import H2OTypeConverters
 from ai.h2o.sparkling.ml.params.HasInitialBiases import HasInitialBiases
 from ai.h2o.sparkling.ml.params.HasInitialWeights import HasInitialWeights
 from ai.h2o.sparkling.ml.params.HasIgnoredCols import HasIgnoredCols
+from ai.h2o.sparkling.ml.params.HasDeprecatedVariableImportances import HasDeprecatedVariableImportances
 
 
-class H2ODeepLearningParams(HasInitialBiases, HasInitialWeights, HasIgnoredCols, Params):
+class H2ODeepLearningParams(HasInitialBiases, HasInitialWeights, HasIgnoredCols, HasDeprecatedVariableImportances, Params):
 
     ##
     # Param definitions
@@ -267,9 +268,9 @@ class H2ODeepLearningParams(HasInitialBiases, HasInitialWeights, HasIgnoredCols,
         """Enable diagnostics for hidden layers.""",
         H2OTypeConverters.toBoolean())
 
-    variableImportances = Param(
+    calculateFeatureImportances = Param(
         Params._dummy(),
-        "variableImportances",
+        "calculateFeatureImportances",
         """Compute variable importances for input features (Gedeon method) - can be slow for large networks.""",
         H2OTypeConverters.toBoolean())
 
@@ -501,6 +502,12 @@ class H2ODeepLearningParams(HasInitialBiases, HasInitialWeights, HasIgnoredCols,
         """Automatically export generated models to this directory.""",
         H2OTypeConverters.toNullableString())
 
+    aucType = Param(
+        Params._dummy(),
+        "aucType",
+        """Set default multinomial AUC type.""",
+        H2OTypeConverters.toEnumString("hex.MultinomialAucType"))
+
     ##
     # Getters
     ##
@@ -624,8 +631,8 @@ class H2ODeepLearningParams(HasInitialBiases, HasInitialWeights, HasIgnoredCols,
     def getDiagnostics(self):
         return self.getOrDefault(self.diagnostics)
 
-    def getVariableImportances(self):
-        return self.getOrDefault(self.variableImportances)
+    def getCalculateFeatureImportances(self):
+        return self.getOrDefault(self.calculateFeatureImportances)
 
     def getFastMode(self):
         return self.getOrDefault(self.fastMode)
@@ -741,6 +748,9 @@ class H2ODeepLearningParams(HasInitialBiases, HasInitialWeights, HasIgnoredCols,
     def getExportCheckpointsDir(self):
         return self.getOrDefault(self.exportCheckpointsDir)
 
+    def getAucType(self):
+        return self.getOrDefault(self.aucType)
+
     ##
     # Setters
     ##
@@ -864,8 +874,8 @@ class H2ODeepLearningParams(HasInitialBiases, HasInitialWeights, HasIgnoredCols,
     def setDiagnostics(self, value):
         return self._set(diagnostics=value)
 
-    def setVariableImportances(self, value):
-        return self._set(variableImportances=value)
+    def setCalculateFeatureImportances(self, value):
+        return self._set(calculateFeatureImportances=value)
 
     def setFastMode(self, value):
         return self._set(fastMode=value)
@@ -980,3 +990,6 @@ class H2ODeepLearningParams(HasInitialBiases, HasInitialWeights, HasIgnoredCols,
 
     def setExportCheckpointsDir(self, value):
         return self._set(exportCheckpointsDir=value)
+
+    def setAucType(self, value):
+        return self._set(aucType=value)
