@@ -222,21 +222,9 @@ class H2OGAMParams(HasIgnoredCols, HasBetaConstraints, HasGamCols, Params):
     numKnots = Param(
         Params._dummy(),
         "numKnots",
-        """Number of knots for gam predictors.  If specified, must specify one for each gam predictor.  For monotone I-splines, mininum = 2, for cs spline, minimum = 3.  For thin plate, minimum is size of polynomial basis + 2.""",
+        """Number of knots for gam predictors""",
         H2OTypeConverters.toNullableListInt())
 
-    splineOrders = Param(
-        Params._dummy(),
-        "splineOrders",
-        """Order of I-splines or NBSplineTypeI M-splines used for gam predictors. If specified, must be the same size as gam_columns.  For I-splines, the spline_orders will be the same as the polynomials used to generate the splines.  For M-splines, the polynomials used to generate the splines will be spline_order-1.  Values for bs=0 or 1 will be ignored.""",
-        H2OTypeConverters.toNullableListInt())
-
-    splinesNonNegative = Param(
-        Params._dummy(),
-        "splinesNonNegative",
-        """Valid for I-spline (bs=2) only.  True if the I-splines are monotonically increasing (and monotonically non-decreasing) and False if the I-splines are monotonically decreasing (and monotonically non-increasing).  If specified, must be the same size as gam_columns.  Values for other spline types will be ignored.  Default to true.""",
-        H2OTypeConverters.toNullableListBoolean())
-
     scale = Param(
         Params._dummy(),
         "scale",
@@ -246,7 +234,7 @@ class H2OGAMParams(HasIgnoredCols, HasBetaConstraints, HasGamCols, Params):
     bs = Param(
         Params._dummy(),
         "bs",
-        """Basis function type for each gam predictors, 0 for cr, 1 for thin plate regression with knots, 2 for monotone I-splines, 3 for NBSplineTypeI M-splines (refer to doc here: https://h2oai.atlassian.net/browse/PUBDEV-8835).  If specified, must be the same size as gam_columns""",
+        """Basis function type for each gam predictors, 0 for cr, 1 for thin plate regression with knots, 2 for thin plate regression with SVD.  If specified, must be the same size as gam_columns""",
         H2OTypeConverters.toNullableListInt())
 
     keepGamCols = Param(
@@ -270,7 +258,7 @@ class H2OGAMParams(HasIgnoredCols, HasBetaConstraints, HasGamCols, Params):
     knotIds = Param(
         Params._dummy(),
         "knotIds",
-        """Array storing frame keys of knots.  One for each gam column set specified in gam_columns""",
+        """String arrays storing frame keys of knots.  One for each gam column set specified in gam_columns""",
         H2OTypeConverters.toNullableListString())
 
     modelId = Param(
@@ -312,7 +300,7 @@ class H2OGAMParams(HasIgnoredCols, HasBetaConstraints, HasGamCols, Params):
     weightCol = Param(
         Params._dummy(),
         "weightCol",
-        """Column with observation weights. Giving some observation a weight of zero is equivalent to excluding it from the dataset; giving an observation a relative weight of 2 is equivalent to repeating that row twice. Negative weights are not allowed. Note: Weights are per-row observation weights and do not increase the size of the data frame. This is typically the number of times a row is repeated, but non-integer values are supported as well. During training, rows with higher weights matter more, due to the larger loss function pre-factor. If you set weight = 0 for a row, the returned prediction frame at that row is zero and this is incorrect. To get an accurate prediction, remove all rows with weight == 0.""",
+        """Column with observation weights. Giving some observation a weight of zero is equivalent to excluding it from the dataset; giving an observation a relative weight of 2 is equivalent to repeating that row twice. Negative weights are not allowed. Note: Weights are per-row observation weights and do not increase the size of the data frame. This is typically the number of times a row is repeated, but non-integer values are supported as well. During training, rows with higher weights matter more, due to the larger loss function pre-factor.""",
         H2OTypeConverters.toNullableString())
 
     offsetCol = Param(
@@ -360,7 +348,7 @@ class H2OGAMParams(HasIgnoredCols, HasBetaConstraints, HasGamCols, Params):
     stoppingMetric = Param(
         Params._dummy(),
         "stoppingMetric",
-        """Metric to use for early stopping (AUTO: logloss for classification, deviance for regression and anomaly_score for Isolation Forest). Note that custom and custom_increasing can only be used in GBM and DRF with the Python client.""",
+        """Metric to use for early stopping (AUTO: logloss for classification, deviance for regression and anonomaly_score for Isolation Forest). Note that custom and custom_increasing can only be used in GBM and DRF with the Python client.""",
         H2OTypeConverters.toEnumString("hex.ScoreKeeper$StoppingMetric"))
 
     stoppingTolerance = Param(
@@ -489,12 +477,6 @@ class H2OGAMParams(HasIgnoredCols, HasBetaConstraints, HasGamCols, Params):
     def getNumKnots(self):
         return self.getOrDefault(self.numKnots)
 
-    def getSplineOrders(self):
-        return self.getOrDefault(self.splineOrders)
-
-    def getSplinesNonNegative(self):
-        return self.getOrDefault(self.splinesNonNegative)
-
     def getScale(self):
         return self.getOrDefault(self.scale)
 
@@ -672,12 +654,6 @@ class H2OGAMParams(HasIgnoredCols, HasBetaConstraints, HasGamCols, Params):
     def setNumKnots(self, value):
         return self._set(numKnots=value)
 
-    def setSplineOrders(self, value):
-        return self._set(splineOrders=value)
-
-    def setSplinesNonNegative(self, value):
-        return self._set(splinesNonNegative=value)
-
     def setScale(self, value):
         return self._set(scale=value)
 
