@@ -24,7 +24,7 @@ from ..model.dim_reduction import H2ODimReductionModel, H2OTargetEncoderMetrics
 from ..model.metrics_base import (H2OBinomialModelMetrics, H2OClusteringModelMetrics, H2ORegressionModelMetrics,
                                   H2OMultinomialModelMetrics, H2OAutoEncoderModelMetrics, H2ODimReductionModelMetrics,
                                   H2OWordEmbeddingModelMetrics, H2OOrdinalModelMetrics, H2OAnomalyDetectionModelMetrics,
-                                  H2OCoxPHModelMetrics)
+                                  H2OModelMetricsRegressionCoxPH)
 from ..model.model_base import ModelBase
 from ..model.multinomial import H2OMultinomialModel
 from ..model.ordinal import H2OOrdinalModel
@@ -332,10 +332,10 @@ class H2OEstimator(ModelBase):
             parms["response_column"] = y
         if not isinstance(x, (list, tuple)):
             x = [x]
-        if is_type(x[0], int):
+        if len(x) > 0 and is_type(x[0], int):
             x = [names[i] for i in x]
         if override_default_training_frame:
-            ignored_columns = list(set(names) - set(x + [y, offset, folds, weights] + self._additional_used_columns(parms)))
+            ignored_columns = list(set(names) - set(x + [y, offset, folds, weights]))
             parms["ignored_columns"] = None if ignored_columns == [] else [quoted(col) for col in ignored_columns]
         parms["interactions"] = (None if "interactions" not in parms or parms["interactions"] is None
                                  else [quoted(col) for col in parms["interactions"]])
@@ -443,6 +443,7 @@ class H2OEstimator(ModelBase):
         if name == "H2OIsolationForestEstimator": return "isolationforest"
         if name in ["H2OPCA", "H2OPrincipalComponentAnalysisEstimator"]: return "pca"
         if name in ["H2OSVD", "H2OSingularValueDecompositionEstimator"]: return "svd"
+        if name == "H2ORuleFitEstimator": return "rulefit"
 
 
     @staticmethod
@@ -525,13 +526,6 @@ class H2OEstimator(ModelBase):
         """
         return True
 
-    def _additional_used_columns(self, parms):
-        """
-        Returns list of additional columns not to automatically add to ignored_columns parameter.
-        :return: Empty list as default. Can be overridden by any specific algorithm.
-        """
-        return []
-
     @staticmethod
     def _metrics_class(model_json):
         model_type = model_json["output"]["model_category"]
@@ -565,7 +559,7 @@ class H2OEstimator(ModelBase):
             valid_metrics_class = H2OBinomialModelMetrics
             model_class = H2OAnomalyDetectionModel
         elif model_type == "CoxPH":
-            metrics_class = H2OCoxPHModelMetrics
+            metrics_class = H2OModelMetricsRegressionCoxPH
             model_class = H2OCoxPHModel
         elif model_type == "TargetEncoder":
             metrics_class = H2OTargetEncoderMetrics
